@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -18,8 +18,8 @@ class KGpgChangePass: public KGpgTransaction {
 
 	Q_DISABLE_COPY(KGpgChangePass)
 public:
-    explicit KGpgChangePass(QObject *parent, const QString &keyid);
-    ~KGpgChangePass() override;
+	explicit KGpgChangePass(QObject *parent, const QString &keyid);
+	~KGpgChangePass() override = default;
 
 protected:
 	bool nextLine(const QString &line) override;
