@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2012-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -47,7 +47,7 @@ public:
 	/**
 	 * @brief destructor
 	 */
-    ~KGpgVerify() override;
+	~KGpgVerify() override = default;
 
 	/**
 	 * @brief get verification report
